==> zzyj-outputvalcount-impl-3.0.0-20230613.003958-179-sources.jar: com/ejianc/business/appliances/bean/MeteringRegisterDetailEntity.java <==
package com.ejianc.business.appliances.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 器具-计量器具登记详情
 * 
 * @author generator
 * 
 */
 @TableName("t_appliances_metering_register_detail")
public class MeteringRegisterDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="metering_name")
    private String meteringName; // 计量器具名称
    @TableField(value="metering_code")
    private String meteringCode; // 器具编号
    @TableField(value="metering_model")
    private String meteringModel; // 器具型号
    @TableField(value="metering_num")
    private Integer meteringNum; // 数量
    @TableField(value="product_area_id")
    private Long productAreaId; // 产地
    @TableField(value="product_area_name")
    private String productAreaName; // 产地名称
    @TableField(value="appraisal_date")
    private Date appraisalDate; // 鉴定日期
    @TableField(value="appraisal_report_code")
    private String appraisalReportCode; // 鉴定报告编号
    @TableField(value="maintenance_date")
    private Date maintenanceDate; // 维保日期
    @TableField(value="status")
    private String status; // 状态（使用/保费）
    @TableField(value="manufacturer")
    private String manufacturer; // 厂商
    @TableField(value="register_id")
    private Long registerId; // 主表登记id
    @TableField(value="metering_status")
    private String meteringStatus; // 工具状态(1-正常 2-异常)
    @TableField(value="use_status")
    private String useStatus; // 使用状态(1-使用 2-未使用)
    @TableField(value="start_date")
    private Date startDate; // 进场日期
    @TableField(value="produce_date")
    private Date produceDate; // 生产日期
    
    
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getMeteringName() {
        return meteringName;
    }

    public void setMeteringName(String meteringName) {
        this.meteringName = meteringName;
    }
    public String getMeteringCode() {
        return meteringCode;
    }

    public void setMeteringCode(String meteringCode) {
        this.meteringCode = meteringCode;
    }
    public String getMeteringModel() {
        return meteringModel;
    }

    public void setMeteringModel(String meteringModel) {
        this.meteringModel = meteringModel;
    }
    public Integer getMeteringNum() {
        return meteringNum;
    }

    public void setMeteringNum(Integer meteringNum) {
        this.meteringNum = meteringNum;
    }
    public Long getProductAreaId() {
        return productAreaId;
    }

    public void setProductAreaId(Long productAreaId) {
        this.productAreaId = productAreaId;
    }
    public String getProductAreaName() {
        return productAreaName;
    }

    public void setProductAreaName(String productAreaName) {
        this.productAreaName = productAreaName;
    }
    public Date getAppraisalDate() {
        return appraisalDate;
    }

    public void setAppraisalDate(Date appraisalDate) {
        this.appraisalDate = appraisalDate;
    }
    public String getAppraisalReportCode() {
        return appraisalReportCode;
    }

    public void setAppraisalReportCode(String appraisalReportCode) {
        this.appraisalReportCode = appraisalReportCode;
    }
    public Date getMaintenanceDate() {
        return maintenanceDate;
    }

    public void setMaintenanceDate(Date maintenanceDate) {
        this.maintenanceDate = maintenanceDate;
    }
    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public Long getRegisterId() {
        return registerId;
    }

    public void setRegisterId(Long registerId) {
        this.registerId = registerId;
    }
    public String getMeteringStatus() {
        return meteringStatus;
    }

    public void setMeteringStatus(String meteringStatus) {
        this.meteringStatus = meteringStatus;
    }
    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getProduceDate() {
        return produceDate;
    }

    public void setProduceDate(Date produceDate) {
        this.produceDate = produceDate;
    }
    
}

==> zzyj-outputvalcount-impl-3.0.0-20230811.044802-224-sources.jar: com/ejianc/business/appliances/bean/MeteringRegisterDetailEntity.java <==
package com.ejianc.business.appliances.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 器具-计量器具登记详情
 * 
 * @author generator
 * 
 */
 @TableName("t_appliances_metering_register_detail")
public class MeteringRegisterDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="bill_code")
    private String billCode; // 单据编码
    @TableField(value="org_id")
    private Long orgId; // 组织id
    @TableField(value="org_name")
    private String orgName; // 组织名称
    @TableField(value="bill_state")
    private Integer billState; // 单据状态
    @TableField(value="create_user_name")
    private String createUserName; // 编制人
    @TableField(value="operator_id")
    private Long operatorId; // 经办人ID
    @TableField(value="operator_name")
    private String operatorName; // 经办人姓名
    @TableField(value="update_user_name")
    private String updateUserName; // 修改者
    @TableField(value="remark")
    private String remark; // 备注
    @TableField(value="metering_name")
    private String meteringName; // 计量器具名称
    @TableField(value="metering_code")
    private String meteringCode; // 器具编号
    @TableField(value="metering_model")
    private String meteringModel; // 器具型号
    @TableField(value="metering_num")
    private Integer meteringNum; // 数量
    @TableField(value="product_area_id")
    private Long productAreaId; // 产地
    @TableField(value="product_area_name")
    private String productAreaName; // 产地名称
    @TableField(value="appraisal_date")
    private Date appraisalDate; // 鉴定日期
    @TableField(value="appraisal_report_code")
    private String appraisalReportCode; // 鉴定报告编号
    @TableField(value="maintenance_date")
    private Date maintenanceDate; // 维保日期
    @TableField(value="status")
    private String status; // 状态（使用/保费）
    @TableField(value="manufacturer")
    private String manufacturer; // 厂商
    @TableField(value="register_id")
    private Long registerId; // 主表登记id
    @TableField(value="metering_status")
    private String meteringStatus; // 工具状态(1-正常 2-异常)
    @TableField(value="use_status")
    private String useStatus; // 使用状态(1-使用 2-未使用)
    @TableField(value="start_date")
    private Date startDate; // 进场日期
    @TableField(value="produce_date")
    private Date produceDate; // 生产日期
    @TableField(value = "doc_id")
    private Long docId;//设备档案id
    

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public String getCreateUserName() {
        return createUserName;
    }

    public void setCreateUserName(String createUserName) {
        this.createUserName = createUserName;
    }
    public Long getOperatorId() {
        return operatorId;
    }

    public void setOperatorId(Long operatorId) {
        this.operatorId = operatorId;
    }
    public String getOperatorName() {
        return operatorName;
    }

    public void setOperatorName(String operatorName) {
        this.operatorName = operatorName;
    }
    public String getUpdateUserName() {
        return updateUserName;
    }

    public void setUpdateUserName(String updateUserName) {
        this.updateUserName = updateUserName;
    }
    public String getRemark() {
        return remark;
    }

    public void setRemark(String remark) {
        this.remark = remark;
    }
    public String getMeteringName() {
        return meteringName;
    }

    public void setMeteringName(String meteringName) {
        this.meteringName = meteringName;
    }
    public String getMeteringCode() {
        return meteringCode;
    }

    public void setMeteringCode(String meteringCode) {
        this.meteringCode = meteringCode;
    }
    public String getMeteringModel() {
        return meteringModel;
    }

    public void setMeteringModel(String meteringModel) {
        this.meteringModel = meteringModel;
    }
    public Integer getMeteringNum() {
        return meteringNum;
    }

    public void setMeteringNum(Integer meteringNum) {
        this.meteringNum = meteringNum;
    }
    public Long getProductAreaId() {
        return productAreaId;
    }

    public void setProductAreaId(Long productAreaId) {
        this.productAreaId = productAreaId;
    }
    public String getProductAreaName() {
        return productAreaName;
    }

    public void setProductAreaName(String productAreaName) {
        this.productAreaName = productAreaName;
    }
    public Date getAppraisalDate() {
        return appraisalDate;
    }

    public void setAppraisalDate(Date appraisalDate) {
        this.appraisalDate = appraisalDate;
    }
    public String getAppraisalReportCode() {
        return appraisalReportCode;
    }

    public void setAppraisalReportCode(String appraisalReportCode) {
        this.appraisalReportCode = appraisalReportCode;
    }
    public Date getMaintenanceDate() {
        return maintenanceDate;
    }

    public void setMaintenanceDate(Date maintenanceDate) {
        this.maintenanceDate = maintenanceDate;
    }
    public String getStatus() {
        return status;
    }

    public void setStatus(String status) {
        this.status = status;
    }
    public String getManufacturer() {
        return manufacturer;
    }

    public void setManufacturer(String manufacturer) {
        this.manufacturer = manufacturer;
    }
    public Long getRegisterId() {
        return registerId;
    }

    public void setRegisterId(Long registerId) {
        this.registerId = registerId;
    }
    public String getMeteringStatus() {
        return meteringStatus;
    }

    public void setMeteringStatus(String meteringStatus) {
        this.meteringStatus = meteringStatus;
    }
    public String getUseStatus() {
        return useStatus;
    }

    public void setUseStatus(String useStatus) {
        this.useStatus = useStatus;
    }
    public Date getStartDate() {
        return startDate;
    }

    public void setStartDate(Date startDate) {
        this.startDate = startDate;
    }
    public Date getProduceDate() {
        return produceDate;
    }

    public void setProduceDate(Date produceDate) {
        this.produceDate = produceDate;
    }

    public Long getDocId() {
        return docId;
    }

    public void setDocId(Long docId) {
        this.docId = docId;
    }
}
